@@ -12,7 +12,7 @@ use warnings;
 
 package Dist::Zilla::Plugin::Git::Init;
 {
-  $Dist::Zilla::Plugin::Git::Init::VERSION = '2.010';
+  $Dist::Zilla::Plugin::Git::Init::VERSION = '2.011';
 }
 # ABSTRACT: initialize git repository on dzil new
 
@@ -58,7 +58,7 @@ sub mvp_aliases { return { config => 'config_entries', remote => 'remotes' } }
 sub after_mint {
     my $self = shift;
     my ($opts) = @_;
-    my $git = Git::Wrapper->new($opts->{mint_root});
+    my $git = Git::Wrapper->new("$opts->{mint_root}");
     $self->log("Initializing a new git repository in " . $opts->{mint_root});
     $git->init;
 
@@ -68,7 +68,7 @@ sub after_mint {
       $git->config($option, $value);
     }
 
-    $git->add($opts->{mint_root});
+    $git->add("$opts->{mint_root}");
     $git->commit({message => _format_string($self->commit_message, $self)});
     foreach my $remoteSpec (@{ $self->remotes }) {
       my ($remote, $url) = split ' ', _format_string($remoteSpec, $self), 2;
@@ -89,7 +89,7 @@ Dist::Zilla::Plugin::Git::Init - initialize git repository on dzil new
 
 =head1 VERSION
 
-version 2.010
+version 2.011
 
 =head1 SYNOPSIS
 
